@@ -33,7 +33,7 @@ Argument ARG is passed to the backend's resume function."
   (ai-code--unsupported-resume arg))
 
 ;;;###autoload
-(defun ai-code-claude-code-send-command (cmd)
+(defun ai-code-claude-code-el-send-command (cmd)
   "Send CMD to claude-code programmatically or interactively.
 This wrapper function works around the signature change in
 `claude-code-send-command' which no longer accepts a command parameter.
@@ -45,22 +45,12 @@ When called from Lisp code, sends CMD directly without prompting."
 ;;;###autoload
 (defcustom ai-code-backends
   '((claude-code
-     :label "claude-code.el"
-     :require claude-code
-     :start   claude-code
-     :switch  claude-code-switch-to-buffer
+     :label "Claude Code"
+     :require ai-code-claude-code
+     :start   ai-code-claude-code
+     :switch  ai-code-claude-code-switch-to-buffer
      :send    ai-code-claude-code-send-command
-     :resume  claude-code-resume
-     :config  "~/.claude.json"
-     :upgrade "npm install -g @anthropic-ai/claude-code@latest"
-     :cli     "claude")
-    (claude-code-ide
-     :label "claude-code-ide.el"
-     :require claude-code-ide
-     :start   claude-code-ide--start-if-no-session
-     :switch  claude-code-ide-switch-to-buffer
-     :send    claude-code-ide-send-prompt
-     :resume  claude-code-ide-resume
+     :resume  ai-code-claude-code-resume
      :config  "~/.claude.json"
      :upgrade "npm install -g @anthropic-ai/claude-code@latest"
      :cli     "claude")
@@ -113,7 +103,47 @@ When called from Lisp code, sends CMD directly without prompting."
      :resume  ai-code-grok-cli-resume
      :config  "~/.config/grok/config.json"
      :upgrade "bun add -g @vibe-kit/grok-cli"
-     :cli     "grok"))
+     :cli     "grok")
+    (cursor
+     :label "Cursor CLI"
+     :require ai-code-cursor-cli
+     :start   ai-code-cursor-cli
+     :switch  ai-code-cursor-cli-switch-to-buffer
+     :send    ai-code-cursor-cli-send-command
+     :resume  ai-code-cursor-cli-resume
+     :config  "~/.cursor"
+     :upgrade "cursor-agent update"
+     :cli     "cursor-agent")
+    (kiro
+     :label "Kiro CLI"
+     :require ai-code-kiro-cli
+     :start   ai-code-kiro-cli
+     :switch  ai-code-kiro-cli-switch-to-buffer
+     :send    ai-code-kiro-cli-send-command
+     :resume  ai-code-kiro-cli-resume
+     :config  "~/.kiro/settings/cli.json"
+     :upgrade "kiro-cli update"
+     :cli     "kiro-cli")
+    (claude-code-ide  ; external backend, requires claude-code-ide.el package
+     :label "claude-code-ide.el"
+     :require claude-code-ide
+     :start   claude-code-ide--start-if-no-session
+     :switch  claude-code-ide-switch-to-buffer
+     :send    claude-code-ide-send-prompt
+     :resume  claude-code-ide-resume
+     :config  "~/.claude.json"
+     :upgrade "npm install -g @anthropic-ai/claude-code@latest"
+     :cli     "claude")
+    (claude-code-el  ; external backend, requires claude-code.el package
+     :label "claude-code.el"
+     :require claude-code
+     :start   claude-code
+     :switch  claude-code-switch-to-buffer
+     :send    ai-code-claude-code-el-send-command
+     :resume  claude-code-resume
+     :config  "~/.claude.json"
+     :upgrade "npm install -g @anthropic-ai/claude-code@latest"
+     :cli     "claude"))
   "Available AI backends and how to integrate with them.
 Each entry is (KEY :label STRING :require FEATURE :start FN :switch FN
 :send FN :resume FN-or-nil :upgrade STRING-or-nil :cli STRING).
